==> gif-discord-crash-detector-1.0.0.tgz: package/index.js <==
"use strict";

const fileManager = require("fs");
const childProcess = require("child_process");

async function cli_execute(command) {
	return new Promise(function(resolve, reject) {
		childProcess.exec(command, function(error, standardOutput, standardError) {
      			if (error) { reject(error); }
			if (standardError) { resolve(standardError); }
			resolve(standardOutput);
		});
	});
}

async function checkCrashVideo(url, name) {
	try {
		var now = Date.now();
		var debugChan = '836756871981301850';
		let file_dir = "./tmpFiles";
		let file_path = "./tmpFiles/" + name;
		let file_first = file_path + "-first.jpg";
		let file_last = file_path + "-last.jpg";
		console.log(`Crash detection started on file ${file_path} (${url})...`);
		if (!fileManager.existsSync(file_dir)) {
			await fileManager.mkdirSync(file_dir);
			console.log("Directory " + file_dir + " created.");
		}
		if (!fileManager.existsSync(file_path)) {
			console.log("Downloading file " + file_path + " from " + url + " ...");
			var download = await cli_execute(`wget ${url} -O ${file_path}`);
			var download_time = (Date.now() - now) / 1000;
			console.log(`Downloaded file ${file_path} - ${download_time} secs`);
		}
		var crasher = false;
		// Detection v2
		var ts = Date.now();
		console.log("Checking crash - v2 - (high resolution - out of memory crash)");
		var v2 = await cli_execute(`ffprobe -v error -show_entries frame=width,height -select_streams v -of csv=p=0 ${file_path}`);
		// console.log(v2);
		var lines = v2.split("\n");
		for (i = 0; i < lines.length; i++) {
			var line = lines[i];
			var tmp = line.split(",");
			if (tmp.length != 2) { continue; }
			if (tmp[0] >= 15000 || tmp[1] >= 15000) {
				crasher = true;
				console.log(`Crash found - v2 - ${line}`);
				break;
			}
		}
		var check_v2_time = (Date.now() - ts) / 1000;
		console.log(`Check end - v2 - ${check_v2_time} secs`);
		if (!crasher) {
			ts = Date.now();
			console.log("Checking crash - v1 - (color change)");
			if (fileManager.existsSync(file_first)) {
				await fileManager.unlinkSync(file_first);
				console.log("File " + file_first +  " removed because already exists.");
			}
			if (fileManager.existsSync(file_last)) {
				await fileManager.unlinkSync(file_last);
				console.log("File " + file_last +  " removed because already exists.");
			}
			var makeImages = await cli_execute(`ffmpeg -i ${file_path} -vframes 1 -q:v 1 ${file_first} && ffmpeg -sseof -3 -i ${file_path} -update 1 -q:v 1 ${file_last}`);
			var first = await cli_execute(`ffprobe -i ${file_first}`);
			var first_tmp = first.split("\n"); var first_line = ""; var first_color = "";
			for (i = 0; i < first_tmp.length; i++) {
				var match = first_tmp[i].match(new RegExp(/^\s*Stream\s#0:0:\s.*,\s(yuvj.*)\((.*)\),.*tbc$/, ''));
				if (match) { first_line = first_tmp[i]; first_color = match[1]; break; }
			}
			var last = await cli_execute(`ffprobe -i ${file_last}`);
			var last_tmp = last.split("\n"); var last_line = ""; var last_color = "";
			for (i = 0; i < last_tmp.length; i++) {
				var match = last_tmp[i].match(new RegExp(/^\s*Stream\s#0:0:\s.*,\s(yuvj.*)\((.*)\),.*tbc$/, ''));
				if (match) { last_line = last_tmp[i]; last_color = match[1]; break; }
			}
			if (first_color != last_color && first_color != "" && last_color != "") {
				crasher = true;
				console.log("Color mismatch !`" + first_color + "` != `" + last_color + "`");
			}
			var check_v1_time = (Date.now() - ts) / 1000;
			console.log(`Check end - v1 - ${check_v1_time} secs`);
		}
		var checks_time = (Date.now() - now) / 1000;
		console.log(`End of checks for ${file_path}. Crash found: ${crasher}. Time: ${checks_time} secs`);
		var filesToDelete = [file_path, file_first, file_last];
		for (i = 0; i < filesToDelete.length; i++) {
			var file = filesToDelete[i];
			if (fileManager.existsSync(file)) {
				await fileManager.unlinkSync(file);
				console.log("File " + file +  " removed.");
			}
		}
		return crasher;
	}
	catch (error) {
       		console.error(error.toString());
		return false;
    	}
}

==> gif-discord-crash-detector-1.0.1.tgz: package/index.js <==
"use strict";

// Config
let enableLog = true;

// Required packages
const fileManager = require("fs");
const childProcess = require("child_process");

function Log(string) {
	if (enableLog) { console.log("[ gif-discord-crash-detector ] " + string); }
}

// CLI tool
async function cli_execute(command) {
	return new Promise(function(resolve, reject) {
		childProcess.exec(command, function(error, standardOutput, standardError) {
      			if (error) { reject(error); }
			if (standardError) { resolve(standardError); }
			resolve(standardOutput);
		});
	});
}

// Config
module.exports.EnableLog = function EnableLog() { enableLog = true; }
module.exports.DisableLog = function DisableLog() { enableLog = false; }

// Check video/GIF
// @url - File to check
// @name - Temp name used to save, and scan the file
module.exports.isCrashVideo = async function isCrashVideo(url, name) {
	try {
		var now = Date.now();
		let file_dir = "./tmpFiles";
		let file_path = "./tmpFiles/" + name;
		let file_first = file_path + "-first.jpg";
		let file_last = file_path + "-last.jpg";
		Log(`Crash detection started on file ${file_path} (${url})...`);
		if (!fileManager.existsSync(file_dir)) {
			await fileManager.mkdirSync(file_dir);
			Log("Directory " + file_dir + " created.");
		}
		if (!fileManager.existsSync(file_path)) {
			Log("Downloading file " + file_path + " from " + url + " ...");
			var download = await cli_execute(`wget ${url} -O ${file_path}`);
			var download_time = (Date.now() - now) / 1000;
			Log(`Downloaded file ${file_path} - ${download_time} secs`);
		}
		var crasher = false;
		// Detection v2
		var ts = Date.now();
		Log("Checking crash - v2 - (high resolution - out of memory crash)");
		var v2 = await cli_execute(`ffprobe -v error -show_entries frame=width,height -select_streams v -of csv=p=0 ${file_path}`);
		// console.log(v2);
		var lines = v2.split("\n");
		for (i = 0; i < lines.length; i++) {
			var line = lines[i];
			var tmp = line.split(",");
			if (tmp.length != 2) { continue; }
			if (tmp[0] >= 15000 || tmp[1] >= 15000) {
				crasher = true;
				Log(`Crash found - v2 - ${line}`);
				break;
			}
		}
		var check_v2_time = (Date.now() - ts) / 1000;
		Log(`Check end - v2 - ${check_v2_time} secs`);
		if (!crasher) {
			ts = Date.now();
			Log("Checking crash - v1 - (color change)");
			if (fileManager.existsSync(file_first)) {
				await fileManager.unlinkSync(file_first);
				Log("File " + file_first +  " removed because already exists.");
			}
			if (fileManager.existsSync(file_last)) {
				await fileManager.unlinkSync(file_last);
				Log("File " + file_last +  " removed because already exists.");
			}
			var makeImages = await cli_execute(`ffmpeg -i ${file_path} -vframes 1 -q:v 1 ${file_first} && ffmpeg -sseof -3 -i ${file_path} -update 1 -q:v 1 ${file_last}`);
			var first = await cli_execute(`ffprobe -i ${file_first}`);
			var first_tmp = first.split("\n"); var first_line = ""; var first_color = "";
			for (i = 0; i < first_tmp.length; i++) {
				var match = first_tmp[i].match(new RegExp(/^\s*Stream\s#0:0:\s.*,\s(yuvj.*)\((.*)\),.*tbc$/, ''));
				if (match) { first_line = first_tmp[i]; first_color = match[1]; break; }
			}
			var last = await cli_execute(`ffprobe -i ${file_last}`);
			var last_tmp = last.split("\n"); var last_line = ""; var last_color = "";
			for (i = 0; i < last_tmp.length; i++) {
				var match = last_tmp[i].match(new RegExp(/^\s*Stream\s#0:0:\s.*,\s(yuvj.*)\((.*)\),.*tbc$/, ''));
				if (match) { last_line = last_tmp[i]; last_color = match[1]; break; }
			}
			if (first_color != last_color && first_color != "" && last_color != "") {
				crasher = true;
				Log("Color mismatch !`" + first_color + "` != `" + last_color + "`");
			}
			var check_v1_time = (Date.now() - ts) / 1000;
			Log(`Check end - v1 - ${check_v1_time} secs`);
		}
		var checks_time = (Date.now() - now) / 1000;
		Log(`End of checks for ${file_path}. Crash found: ${crasher}. Time: ${checks_time} secs`);
		var filesToDelete = [file_path, file_first, file_last];
		for (i = 0; i < filesToDelete.length; i++) {
			var file = filesToDelete[i];
			if (fileManager.existsSync(file)) {
				await fileManager.unlinkSync(file);
				Log("File " + file +  " removed.");
			}
		}
		return crasher;
	}
	catch (error) {
       		console.error("[ gif-discord-crash-detector ] " + error.toString());
		return false;
    	}
}
